@@ -59,8 +59,8 @@ static NTSTATUS start_pdo(struct device_object *pdo)
 	/* 64-bit broadcom driver doesn't work if DMA is allocated
 	 * from over 1GB */
 	if (wd->vendor == 0x14e4) {
-		if (pci_set_dma_mask(pdev, 0x3fffffff) ||
-		    pci_set_consistent_dma_mask(pdev, 0x3fffffff))
+		if (pci_set_dma_mask(pdev, DMA_30BIT_MASK) ||
+		    pci_set_consistent_dma_mask(pdev, DMA_30BIT_MASK))
 			WARNING("couldn't set DMA mask; this driver "
 				"may not work with more than 1GB RAM");
 	}
@@ -76,12 +76,11 @@ static NTSTATUS start_pdo(struct device_object *pdo)
 	resources_size = sizeof(struct cm_resource_list) +
 		sizeof(struct cm_partial_resource_descriptor) * count;
 	TRACE2("resources: %d, %d", count, resources_size);
-	wd->resource_list = kmalloc(resources_size, GFP_KERNEL);
+	wd->resource_list = kzalloc(resources_size, GFP_KERNEL);
 	if (!wd->resource_list) {
 		WARNING("couldn't allocate memory");
 		goto err_regions;
 	}
-	memset(wd->resource_list, 0, resources_size);
 	wd->resource_list->count = 1;
 	wd->resource_list->list[0].interface_type = PCIBus;
 	/* bus_number is not used by WDM drivers */
@@ -217,7 +216,7 @@ wstdcall NTSTATUS IoSendIrpTopDev(struct device_object *dev_obj, ULONG major_fn,
 }
 
 wstdcall NTSTATUS pdoDispatchDeviceControl(struct device_object *pdo,
-					  struct  irp *irp)
+					   struct  irp *irp)
 {
 	struct io_stack_location *irp_sl;
 	NTSTATUS status;
@@ -330,7 +329,7 @@ wstdcall NTSTATUS pdoDispatchPower(struct device_object *pdo, struct irp *irp)
 	case IRP_MN_SET_POWER:
 		power_state = irp_sl->params.power.state;
 		if (power_state.device_state == PowerDeviceD0) {
-			TRACE2("resuming device %p", wd);
+			TRACE2("resuming %p", wd);
 			if (wrap_is_pci_bus(wd->dev_bus)) {
 				pdev = wd->pci.pdev;
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
@@ -338,6 +337,13 @@ wstdcall NTSTATUS pdoDispatchPower(struct device_object *pdo, struct irp *irp)
 #else
 				pci_restore_state(pdev, wd->pci.pci_state);
 #endif
+				if (wd->pci.wake_state == PowerDeviceD3) {
+					pci_enable_wake(wd->pci.pdev,
+							PCI_D3hot, 0);
+					pci_enable_wake(wd->pci.pdev,
+							PCI_D3cold, 0);
+				}
+				pci_set_power_state(pdev, PCI_D0);
 			} else { // usb device
 #ifdef CONFIG_USB
 				wrap_resume_urbs(wd);
@@ -352,6 +358,14 @@ wstdcall NTSTATUS pdoDispatchPower(struct device_object *pdo, struct irp *irp)
 #else
 				pci_save_state(pdev, wd->pci.pci_state);
 #endif
+				TRACE2("%d", wd->pci.wake_state);
+				if (wd->pci.wake_state == PowerDeviceD3) {
+					pci_enable_wake(wd->pci.pdev,
+							PCI_D3hot, 1);
+					pci_enable_wake(wd->pci.pdev,
+							PCI_D3cold, 1);
+				}
+				pci_set_power_state(pdev, PCI_D3hot);
 			} else { // usb device
 #ifdef CONFIG_USB
 				wrap_suspend_urbs(wd);
@@ -613,7 +627,7 @@ int wrap_pnp_start_pci_device(struct pci_dev *pdev,
 	return wrap_pnp_start_device(wd);
 }
 
-void __devexit wrap_pnp_remove_pci_device(struct pci_dev *pdev)
+void wrap_pnp_remove_pci_device(struct pci_dev *pdev)
 {
 	struct wrap_device *wd;
 
@@ -712,10 +726,11 @@ void __devexit wrap_pnp_remove_usb_device(struct usb_interface *intf)
 	struct wrap_device *wd;
 
 	wd = (struct wrap_device *)usb_get_intfdata(intf);
-	ENTER1("%p, %p", intf, wd);
+	TRACE1("%p, %p", intf, wd);
 	if (wd == NULL)
 		EXIT1(return);
 	usb_set_intfdata(intf, NULL);
+	wd->usb.intf = NULL;
 	pnp_remove_device(wd);
 }
 
@@ -757,6 +772,7 @@ void __devexit wrap_pnp_remove_usb_device(struct usb_device *udev, void *ptr)
 	if (wd == NULL)
 		EXIT1(return);
 	intf = wd->usb.intf;
+	wd->usb.intf = NULL;
 	pnp_remove_device(wd);
 }
 #endif
